summaryrefslogtreecommitdiffstats
path: root/src/gui/general/PixmapFunctions.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-09-06 20:59:29 +0000
commit11f31c37e5fa4889d9989f10272f44845449cb7b (patch)
tree4383da04a76c497950d957fc6120b0fd0d9082c2 /src/gui/general/PixmapFunctions.h
parent832eb69d571e8e518db45d0c0e6fbc0f00690209 (diff)
downloadrosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.tar.gz
rosegarden-11f31c37e5fa4889d9989f10272f44845449cb7b.zip
Initial TQt conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1172292 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/general/PixmapFunctions.h')
-rw-r--r--src/gui/general/PixmapFunctions.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/gui/general/PixmapFunctions.h b/src/gui/general/PixmapFunctions.h
index 22da0f0..ea05693 100644
--- a/src/gui/general/PixmapFunctions.h
+++ b/src/gui/general/PixmapFunctions.h
@@ -26,8 +26,8 @@
#ifndef _RG_PIXMAPFUNCTIONS_H_
#define _RG_PIXMAPFUNCTIONS_H_
-#include <qbitmap.h>
-#include <qpixmap.h>
+#include <tqbitmap.h>
+#include <tqpixmap.h>
#include <utility>
@@ -41,7 +41,7 @@ class PixmapFunctions
public:
/**
* Generate a heuristic mask for the given pixmap. Unlike
* QPixmap::createHeuristicMask, this removes from the mask all
* pixels that are apparently "background" even if they appear in
* holes in the middle of the image. This is more usually what we
* want than the default behaviour of createHeuristicMask.
@@ -50,11 +50,11 @@ public:
*
* This function is slow.
*/
- static QBitmap generateMask(const QPixmap &map, const QRgb &rgb);
+ static TQBitmap generateMask(const TQPixmap &map, const QRgb &rgb);
/**
* Generate a heuristic mask for the given pixmap. Unlike
* QPixmap::createHeuristicMask, this removes from the mask all
* pixels that are apparently "background" even if they appear in
* holes in the middle of the image. This is more usually what we
* want than the default behaviour of createHeuristicMask.
@@ -64,31 +64,31 @@ public:
*
* This function is slow.
*/
- static QBitmap generateMask(const QPixmap &map);
+ static TQBitmap generateMask(const TQPixmap &map);
/**
* Colour a greyscale pixmap with the given hue.
* minValue specifies the minimum value (in the HSV sense) that
* will be used for any recoloured pixel.
*/
- static QPixmap colourPixmap(const QPixmap &map, int hue, int minValue);
+ static TQPixmap colourPixmap(const TQPixmap &map, int hue, int minValue);
/**
* Make a pixmap grey, or otherwise reduce its intensity.
*/
- static QPixmap shadePixmap(const QPixmap &map);
+ static TQPixmap shadePixmap(const TQPixmap &map);
- /// Return a QPixmap that is a mirror image of map (including mask)
- static QPixmap flipVertical(const QPixmap &map);
+ /// Return a TQPixmap that is a mirror image of map (including mask)
+ static TQPixmap flipVertical(const TQPixmap &map);
- /// Return a QPixmap that is a mirror image of map (including mask)
- static QPixmap flipHorizontal(const QPixmap &map);
+ /// Return a TQPixmap that is a mirror image of map (including mask)
+ static TQPixmap flipHorizontal(const TQPixmap &map);
/// Return left and right parts of the QPixmap
- static std::pair<QPixmap, QPixmap> splitPixmap(const QPixmap &original, int x);
+ static std::pair<TQPixmap, TQPixmap> splitPixmap(const TQPixmap &original, int x);
/**
- * Using QPainter::drawPixmap to draw one pixmap on another does
+ * Using TQPainter::drawPixmap to draw one pixmap on another does
* not appear to take the mask into account properly. Background
* pixels in the second pixmap erase foreground pixels in the
* first one, regardless of whether they're masked or not. This
@@ -96,9 +96,9 @@ public:
*
* Note that the source pixmap _must_ have a mask.
*/
- static void drawPixmapMasked(QPixmap &dest, QBitmap &destMask,
+ static void drawPixmapMasked(TQPixmap &dest, TQBitmap &destMask,
int x, int y,
- const QPixmap &source);
+ const TQPixmap &source);
};
@@ -41,7 +41,7 @@ class PixmapFunctions
/**
* Generate a heuristic mask for the given pixmap. Unlike
- * QPixmap::createHeuristicMask, this removes from the mask all
+ * TQPixmap::createHeuristicMask, this removes from the mask all
* pixels that are apparently "background" even if they appear in
* holes in the middle of the image. This is more usually what we
@@ -50,11 +50,11 @@ public:
/**
* Generate a heuristic mask for the given pixmap. Unlike
- * QPixmap::createHeuristicMask, this removes from the mask all
+ * TQPixmap::createHeuristicMask, this removes from the mask all
* pixels that are apparently "background" even if they appear in
* holes in the middle of the image. This is more usually what we